@@ -29,12 +29,13 @@
 #define NV_MAX_DEVICES 32
 
 typedef struct {
-    NvU32    domain;        /* PCI domain number */
-    NvU8     bus;           /* PCI bus number    */
-    NvU8     slot;          /* PCI slot number   */
-    NvU16    vendor_id;     /* PCI vendor ID     */
-    NvU16    device_id;     /* PCI device ID     */
-    NvBool   valid;         /* validation flag   */
+    NvU32    domain;        /* PCI domain number   */
+    NvU8     bus;           /* PCI bus number      */
+    NvU8     slot;          /* PCI slot number     */
+    NvU8     function;      /* PCI function number */
+    NvU16    vendor_id;     /* PCI vendor ID       */
+    NvU16    device_id;     /* PCI device ID       */
+    NvBool   valid;         /* validation flag     */
 } nv_pci_info_t;
 
 /* NOTE: using an ioctl() number > 55 will overflow! */
@@ -343,7 +344,7 @@ typedef struct
 #define NV_FLAG_MAP_REGS_EARLY         0x0008
 #define NV_FLAG_USE_BAR0_CFG           0x0010
 #define NV_FLAG_USES_MSI               0x0020
-#define NV_FLAG_S4_AVAILABLE           0x0040
+// EMPTY SLOT                          0x0040
 #define NV_FLAG_PASSTHRU               0x0080
 #define NV_FLAG_GVI_IN_SUSPEND         0x0100
 #define NV_FLAG_GVI                    0x0200
@@ -351,6 +352,7 @@ typedef struct
 #define NV_FLAG_PERSISTENT_SW_STATE    0x0800
 #define NV_FLAG_IN_RECOVERY            0x1000
 #define NV_FLAG_SKIP_CFG_CHECK         0x2000
+#define NV_FLAG_UNBIND_LOCK            0x4000
 
 #define NV_PM_ACPI_HIBERNATE    0x0001
 #define NV_PM_ACPI_STANDBY      0x0002
@@ -415,6 +417,8 @@ typedef struct
 #define NV_I2C_CMD_SMBUS_WRITE       4
 #define NV_I2C_CMD_SMBUS_QUICK_WRITE 5
 #define NV_I2C_CMD_SMBUS_QUICK_READ  6
+#define NV_I2C_CMD_SMBUS_BLOCK_READ  7
+#define NV_I2C_CMD_SMBUS_BLOCK_WRITE 8
 
 /*
 ** where we hide our nv_state_t * ...
@@ -584,6 +588,7 @@ RM_STATUS  NV_API_CALL  rm_get_vbios_version     (nv_stack_t *, nv_state_t *, Nv
 RM_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 RM_STATUS  NV_API_CALL  rm_get_gpu_uuid_raw      (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 void       NV_API_CALL  rm_free_unused_clients   (nv_stack_t *, nv_state_t *, void *);
+void       NV_API_CALL  rm_unbind_lock           (nv_stack_t *, nv_state_t *);
 
 RM_STATUS  NV_API_CALL  rm_read_registry_dword   (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
 RM_STATUS  NV_API_CALL  rm_write_registry_dword  (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32);
@@ -639,6 +644,13 @@ RM_STATUS  NV_API_CALL  rm_gpu_ops_channel_destroy(nv_stack_t *, nvgpuChannelHan
 const char*  NV_API_CALL  rm_gpu_ops_channel_translate_error(nv_stack_t *, NvU32);
 RM_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_allocate(nv_stack_t *, nvgpuChannelHandle_t, NvU32, NvU32*, nvgpuObjectHandle_t *);
 RM_STATUS  NV_API_CALL rm_gpu_ops_memory_free(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
+RM_STATUS  NV_API_CALL rm_gpu_ops_query_caps(nv_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuCaps_t);
+RM_STATUS  NV_API_CALL rm_gpu_ops_get_attached_uuids(nv_stack_t *, NvU8 *pUuidList, unsigned *numGpus);
+RM_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_arch(nv_stack_t *, NvU8 *pUuid, unsigned uuidLength, NvU32 *pGpuArch);
+RM_STATUS  NV_API_CALL rm_gpu_ops_get_uvm_priv_region(NvU64 *pPrivRegionStart, NvU64 *pPrivRegionLength);
+RM_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nv_stack_t *, nvgpuChannelHandle_t);
+RM_STATUS  NV_API_CALL rm_gpu_ops_check_ecc_error_slowpath(nv_stack_t *, nvgpuChannelHandle_t, NvBool *);
+RM_STATUS  NV_API_CALL rm_gpu_ops_kill_channel(nv_stack_t *, nvgpuChannelHandle_t);
 
 #endif /* NVWATCH */
 
