@@ -149,7 +149,8 @@ BOOL        NV_API_CALL  os_pat_supported            (void);
 void        NV_API_CALL  os_dump_stack               (void);
 BOOL        NV_API_CALL  os_is_efi_enabled           (void);
 NvBool      NV_API_CALL  os_is_xen_dom0              (void);
-RM_STATUS   NV_API_CALL  os_get_efi_screen_info      (NvU64 *, NvU32 *, NvU32 *, NvU32 *);
+NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
+RM_STATUS   NV_API_CALL  os_get_efi_screen_info      (NvU64 *, NvU32 *, NvU32 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
 
 /*
@@ -220,6 +221,6 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define RM_PAGES_TO_OS_PAGES(count) (((count) + RM_PAGES_PER_OS_PAGES - 1) \
                                        / RM_PAGES_PER_OS_PAGES)
 
-#define IS_VGX_HYPER()              os_is_xen_dom0()
+#define IS_VGX_HYPER()              os_is_vgx_hyper()
 
 #endif /* _OS_INTERFACE_H_ */
